@@ -82,10 +82,14 @@ class BaseCMLTest(unittest.TestCase):
     def get_alt_title(self):
         return "Other Lab"
 
+    def get_cml23_id(self):
+        return "88119b68-9d08-40c4-90f5-6dc533fd0254"
+
     def setup_mocks(self, m):
         m.get(self.get_api_path("labs"), json=MockCMLServer.get_labs)
         m.get(self.get_api_path("populate_lab_tiles"), json=MockCMLServer.get_lab_tiles)
         m.get(self.get_api_path("labs/{}/download".format(self.get_test_id())), text=MockCMLServer.download_lab)
+        m.get(self.get_api_path("labs/{}/download".format(self.get_cml23_id())), text=MockCMLServer.download_lab_23)
         m.get(
             self.get_api_path("labs/{}/topology?exclude_configurations=False".format(self.get_test_id())), json=MockCMLServer.get_topology
         )
@@ -93,19 +97,30 @@ class BaseCMLTest(unittest.TestCase):
             self.get_api_path("labs/{}/topology?exclude_configurations=False".format(self.get_alt_id())),
             json=MockCMLServer.get_alt_topology,
         )
+        m.get(
+            self.get_api_path("labs/{}/topology?exclude_configurations=False".format(self.get_cml23_id())),
+            json=MockCMLServer.get_topology_23,
+        )
         m.get(self.get_api_path("labs/{}/topology?exclude_configurations=True".format(self.get_test_id())), json=MockCMLServer.get_topology)
         m.get(
             self.get_api_path("labs/{}/topology?exclude_configurations=True".format(self.get_alt_id())),
             json=MockCMLServer.get_alt_topology,
         )
+        m.get(
+            self.get_api_path("labs/{}/topology?exclude_configurations=True".format(self.get_cml23_id())),
+            json=MockCMLServer.get_topology_23,
+        )
         m.get(self.get_api_path("labs/{}/download".format(self.get_alt_id())), text=MockCMLServer.download_alt_lab)
         m.get(self.get_api_path("labs/{}/lab_element_state".format(self.get_test_id())), json=MockCMLServer.get_lab_element_state)
+        m.get(self.get_api_path("labs/{}/lab_element_state".format(self.get_cml23_id())), json=MockCMLServer.get_lab_element_state_23)
         m.get(self.get_api_path("system_information"), json=MockCMLServer.get_sys_info)
         m.get(self.get_api_path("authok"), text=MockCMLServer.auth_ok)
         m.post(self.get_api_path("authenticate"), text=MockCMLServer.authenticate)
         m.get(self.get_api_path("labs/{}/state".format(self.get_test_id())), json="STARTED")
+        m.get(self.get_api_path("labs/{}/state".format(self.get_cml23_id())), json="STARTED")
         m.get(self.get_api_path("labs/{}/state".format(self.get_alt_id())), json="STOPPED")
         m.get(self.get_api_path("labs/{}/check_if_converged".format(self.get_test_id())), json=True)
+        m.get(self.get_api_path("labs/{}/check_if_converged".format(self.get_cml23_id())), json=True)
 
     def add_debug_mock(self, m):
         m.register_uri(requests_mock.ANY, requests_mock.ANY, text=MockCMLServer.print_req)
