@@ -48,6 +48,73 @@ class MockCMLServer(object):
                         "links": [{"id": "l0", "node_a": "n0", "node_b": "n1", "state": "STOPPED"}],
                     },
                 },
+                "88119b68-9d08-40c4-90f5-6dc533fd0254": {
+                    "state": "STARTED",
+                    "created": "2020-08-18 22:47:56",
+                    "lab_title": "Mock Test 2.3",
+                    "lab_description": "",
+                    "node_count": 2,
+                    "link_count": 1,
+                    "id": "88119b68-9d08-40c4-90f5-6dc533fd0254",
+                    "owner": "admin",
+                    "topology": {
+                        "nodes": [
+                            {
+                                "id": "88119b68-9d08-40c4-90f5-6dc533fd0255",
+                                "label": "Lab Net",
+                                "x": -400,
+                                "y": 0,
+                                "node_definition": "external_connector",
+                                "image_definition": None,
+                                "state": "BOOTED",
+                                "cpus": None,
+                                "cpu_limit": None,
+                                "ram": None,
+                                "data_volume": None,
+                                "boot_disk_size": None,
+                                "tags": [],
+                            },
+                            {
+                                "id": "88119b68-9d08-40c4-90f5-6dc533fd0256",
+                                "label": "rtr-1",
+                                "x": -200,
+                                "y": -50,
+                                "node_definition": "iosxrv9000",
+                                "image_definition": "iosxrv9000-6-6-2",
+                                "state": "BOOTED",
+                                "cpus": None,
+                                "cpu_limit": None,
+                                "ram": None,
+                                "data_volume": None,
+                                "boot_disk_size": None,
+                                "tags": [],
+                            },
+                            {
+                                "id": "88119b68-9d08-40c4-90f5-6dc533fd0257",
+                                "label": "rtr-2",
+                                "x": -200,
+                                "y": -50,
+                                "node_definition": "iosxrv9000",
+                                "image_definition": "iosxrv9000-6-6-2",
+                                "state": "DEFINED_ON_CORE",
+                                "cpus": None,
+                                "cpu_limit": None,
+                                "ram": None,
+                                "data_volume": None,
+                                "boot_disk_size": None,
+                                "tags": [],
+                            },
+                        ],
+                        "links": [
+                            {
+                                "id": "88119b68-9d08-40c4-90f5-6dc533fd0258",
+                                "node_a": "88119b68-9d08-40c4-90f5-6dc533fd0256",
+                                "node_b": "88119b68-9d08-40c4-90f5-6dc533fd0255",
+                                "state": "STARTED",
+                            }
+                        ],
+                    },
+                },
                 "5f0d96": {
                     "state": "STARTED",
                     "created": "2020-08-18 22:47:56",
@@ -125,7 +192,7 @@ class MockCMLServer(object):
                 },
                 "is_licensed": True,
             },
-            "system_information": {"version": "2.1.0-b89.f8805559", "ready": True},
+            "system_information": {"version": "2.3.0", "ready": True},
             "system_stats": {
                 "clusters": {
                     "cluster_1": {
@@ -151,7 +218,7 @@ class MockCMLServer(object):
 
     @staticmethod
     def get_labs(req, ctx):
-        response = ["5eaea5", "5f0d96"]
+        response = ["5eaea5", "5f0d96", "88119b68-9d08-40c4-90f5-6dc533fd0254"]
         return response
 
     @staticmethod
@@ -275,6 +342,127 @@ class MockCMLServer(object):
         """
         return response
 
+    @staticmethod
+    def download_lab_23(req, ctx):
+        response = """
+        lab:
+          description: ''
+          notes: ''
+          timestamp: 1597805276.8213837
+          title: Mock Test 2.3
+          version: 0.0.3
+        nodes:
+          - id: 88119b68-9d08-40c4-90f5-6dc533fd0255
+            label: Lab Net
+            node_definition: external_connector
+            x: -400
+            y: 0
+            configuration: bridge0
+            tags: []
+            interfaces:
+              - id: i0
+                slot: 0
+                label: port
+                type: physical
+          - id: 88119b68-9d08-40c4-90f5-6dc533fd0256
+            label: rtr-1
+            node_definition: iosxrv9000
+            x: -200
+            y: -50
+            configuration: |-
+              hostname changeme
+              username cisco
+              group root-lr
+              group cisco-support
+              password cisco
+              !
+              username admin
+              group root-lr
+              group cisco-support
+              password admin
+              !
+              username lab
+              group root-lr
+              group cisco-support
+              password lab
+              !
+              end
+            image_definition: iosxrv9000-6-6-2
+            tags: []
+            interfaces:
+              - id: 88119b68-9d08-40c4-90f5-6dc533fd020a
+                label: Loopback0
+                type: loopback
+              - id: 88119b68-9d08-40c4-90f5-6dc533fd020b
+                slot: 0
+                label: MgmtEth0/RP0/CPU0/0
+                type: physical
+              - id: 88119b68-9d08-40c4-90f5-6dc533fd020c
+                slot: 1
+                label: donotuse1
+                type: physical
+              - id: 88119b68-9d08-40c4-90f5-6dc533fd020d
+                slot: 2
+                label: donotuse2
+                type: physical
+              - id: 88119b68-9d08-40c4-90f5-6dc533fd020e
+                slot: 3
+                label: GigabitEthernet0/0/0/0
+                type: physical
+          - id: 88119b68-9d08-40c4-90f5-6dc533fd0257
+            label: rtr-2
+            node_definition: iosxrv9000
+            x: -200
+            y: -50
+            configuration: |-
+              hostname changeme
+              username cisco
+              group root-lr
+              group cisco-support
+              password cisco
+              !
+              username admin
+              group root-lr
+              group cisco-support
+              password admin
+              !
+              username lab
+              group root-lr
+              group cisco-support
+              password lab
+              !
+              end
+            image_definition: iosxrv9000-6-6-2
+            tags: []
+            interfaces:
+              - id: 88119b68-9d08-40c4-90f5-6dc533fd021a
+                label: Loopback0
+                type: loopback
+              - id: 88119b68-9d08-40c4-90f5-6dc533fd021b
+                slot: 0
+                label: MgmtEth0/RP0/CPU0/0
+                type: physical
+              - id: 88119b68-9d08-40c4-90f5-6dc533fd021c
+                slot: 1
+                label: donotuse1
+                type: physical
+              - id: 88119b68-9d08-40c4-90f5-6dc533fd021d
+                slot: 2
+                label: donotuse2
+                type: physical
+              - id: 88119b68-9d08-40c4-90f5-6dc533fd021e
+                slot: 3
+                label: GigabitEthernet0/0/0/0
+                type: physical
+        links:
+          - id: l0
+            i1: i1
+            n1: n1
+            i2: i0
+            n2: n0
+        """
+        return response
+
     @staticmethod
     def download_alt_lab(req, ctx):
         response = """
@@ -369,7 +557,7 @@ class MockCMLServer(object):
 
     @staticmethod
     def get_sys_info(req, ctx):
-        response = {"version": "2.1.0", "ready": True}
+        response = {"version": "2.3.0", "ready": True}
         return response
 
     @staticmethod
@@ -390,6 +578,10 @@ class MockCMLServer(object):
     def get_lab_element_state(req, ctx):
         return MockCMLServer._get_lab_element_state(req, ctx)
 
+    @staticmethod
+    def get_lab_element_state_23(req, ctx):
+        return MockCMLServer._get_lab_element_state_23(req, ctx)
+
     @staticmethod
     def get_lab_element_state_down(req, ctx):
         return MockCMLServer._get_lab_element_state(req, ctx, "STOPPED")
@@ -403,6 +595,26 @@ class MockCMLServer(object):
         }
         return response
 
+    @staticmethod
+    def _get_lab_element_state_23(req, ctx, n2_state="BOOTED"):
+        response = {
+            "nodes": {
+                "88119b68-9d08-40c4-90f5-6dc533fd0255": "BOOTED",
+                "88119b68-9d08-40c4-90f5-6dc533fd0256": n2_state,
+                "88119b68-9d08-40c4-90f5-6dc533fd0257": "DEFINED_ON_CORE",
+            },
+            "links": {"88119b68-9d08-40c4-90f5-6dc533fd0259": "STARTED"},
+            "interfaces": {
+                "88119b68-9d08-40c4-90f5-6dc533fd020a": "STARTED",
+                "88119b68-9d08-40c4-90f5-6dc533fd020b": "STARTED",
+                "88119b68-9d08-40c4-90f5-6dc533fd020c": "STARTED",
+                "88119b68-9d08-40c4-90f5-6dc533fd020d": "STARTED",
+                "88119b68-9d08-40c4-90f5-6dc533fd020e": "STARTED",
+                "88119b68-9d08-40c4-90f5-6dc533fd020f": "STARTED",
+            },
+        }
+        return response
+
     @staticmethod
     def get_topology(req, ctx):
         response = {
@@ -544,3 +756,112 @@ class MockCMLServer(object):
             "version": "0.0.3",
         }
         return response
+
+    @staticmethod
+    def get_topology_23(req, ctx):
+        response = {
+            "nodes": [
+                {
+                    "id": "88119b68-9d08-40c4-90f5-6dc533fd0255",
+                    "data": {
+                        "node_definition": "external_connector",
+                        "image_definition": None,
+                        "label": "Lab Net",
+                        "configuration": "bridge0",
+                        "x": -400,
+                        "y": 0,
+                        "state": "BOOTED",
+                        "ram": None,
+                        "cpus": None,
+                        "cpu_limit": None,
+                        "data_volume": None,
+                        "boot_disk_size": None,
+                        "tags": [],
+                    },
+                },
+                {
+                    "id": "88119b68-9d08-40c4-90f5-6dc533fd0256",
+                    "data": {
+                        "node_definition": "iosxrv9000",
+                        "image_definition": "iosxrv9000-6-6-2",
+                        "label": "rtr-1",
+                        "configuration": "hostname changeme\n",
+                        "x": -200,
+                        "y": -50,
+                        "state": "BOOTED",
+                        "ram": None,
+                        "cpus": None,
+                        "cpu_limit": None,
+                        "data_volume": None,
+                        "boot_disk_size": None,
+                        "tags": [],
+                    },
+                },
+                {
+                    "id": "88119b68-9d08-40c4-90f5-6dc533fd0257",
+                    "data": {
+                        "node_definition": "iosxrv9000",
+                        "image_definition": "iosxrv9000-6-6-2",
+                        "label": "rtr-2",
+                        "configuration": "hostname changeme\n",
+                        "x": -200,
+                        "y": -50,
+                        "state": "DEFINED_ON_CORE",
+                        "ram": None,
+                        "cpus": None,
+                        "cpu_limit": None,
+                        "data_volume": None,
+                        "boot_disk_size": None,
+                        "tags": [],
+                    },
+                },
+            ],
+            "links": [
+                {
+                    "id": "88119b68-9d08-40c4-90f5-6dc533fd0259",
+                    "interface_a": "88119b68-9d08-40c4-90f5-6dc533fd020c",
+                    "interface_b": "88119b68-9d08-40c4-90f5-6dc533fd020a",
+                    "data": {"state": "STARTED"},
+                }
+            ],
+            "interfaces": [
+                {
+                    "id": "88119b68-9d08-40c4-90f5-6dc533fd020a",
+                    "node": "88119b68-9d08-40c4-90f5-6dc533fd0255",
+                    "data": {"label": "port", "slot": 0, "state": "STARTED", "type": "physical"},
+                },
+                {
+                    "id": "88119b68-9d08-40c4-90f5-6dc533fd020b",
+                    "node": "88119b68-9d08-40c4-90f5-6dc533fd0256",
+                    "data": {"label": "Loopback0", "slot": None, "state": "STARTED", "type": "loopback"},
+                },
+                {
+                    "id": "88119b68-9d08-40c4-90f5-6dc533fd020c",
+                    "node": "88119b68-9d08-40c4-90f5-6dc533fd0256",
+                    "data": {"label": "MgmtEth0/RP0/CPU0/0", "slot": 0, "state": "STARTED", "type": "physical"},
+                },
+                {
+                    "id": "88119b68-9d08-40c4-90f5-6dc533fd020d",
+                    "node": "88119b68-9d08-40c4-90f5-6dc533fd0256",
+                    "data": {"label": "donotuse1", "slot": 1, "state": "STARTED", "type": "physical"},
+                },
+                {
+                    "id": "88119b68-9d08-40c4-90f5-6dc533fd020e",
+                    "node": "88119b68-9d08-40c4-90f5-6dc533fd0256",
+                    "data": {"label": "donotuse2", "slot": 2, "state": "STARTED", "type": "physical"},
+                },
+                {
+                    "id": "88119b68-9d08-40c4-90f5-6dc533fd020f",
+                    "node": "88119b68-9d08-40c4-90f5-6dc533fd0256",
+                    "data": {"label": "GigabitEthernet0/0/0/0", "slot": 3, "state": "STARTED", "type": "physical"},
+                },
+            ],
+            "lab_notes": "",
+            "lab_title": "Mock Test 2.3",
+            "lab_description": "",
+            "state": "STARTED",
+            "created_timestamp": 1597805276.8213837,
+            "cluster_id": "cluster_1",
+            "version": "0.0.3",
+        }
+        return response
