@@ -31,7 +31,12 @@ def console(node, display, **kwargs):
 
             if node_obj.node_definition not in skip_types:
                 if node_obj.is_active():
-                    console = "/{}/{}/0".format(lab.id, node_obj.id)
+                    if len(lab.id) == 6:
+                        # Old-style (CML 2.2) lab IDs; console uses lab_id/node_id
+                        console = "/{}/{}/0".format(lab.id, node_obj.id)
+                    else:
+                        # From CML 2.3, console uses lab_title/node_label
+                        console = "/{}/{}/0".format(lab.title, node_obj.label)
                     if display:
                         try:
                             pl = ViewerPlugin(viewer="console")
